#include "Zmaxdef.h"

c         rigidity cut related commons
c     *******************************
      integer maxAzm, maxZen, maxDim
      parameter (
#ifdef MAX_AZM
     * maxAzm = MAX_AZM,
#else
     * maxAzm = 37, 
#endif
#ifdef MAX_ZEN
     * maxZen=MAX_ZEN,
#else
     * maxZen=21,
#endif
     * maxDim=maxAzm* maxZen)
      real*8  RigCutTbl, DAzm, DZen, Longi, Latit
      integer	AzmSize, ZenSize
      real*8  MagDec, MinAzm, MinZen
      common /Zrigcut/ RigCutTbl(maxDim), Longi, Latit, MagDec,
     *  DAzm, DZen, MinAzm, MinZen, AzmSize, ZenSize

      character*16 Place
      character*3  AzmValue, ZenValue
      common /Zrigcutc/ Place, AzmValue, ZenValue
c     *****************************
